@@ -12,28 +12,27 @@
 ## global variable needed for flat.R
 ##  unlockBinding(".OkTyp", asNamespace("distr"))
     msga <- gettext(
-    "Attention: Arithmetics on distribution objects are understood as\n"
+    "Attention: Arithmetics on distribution objects are understood as "
                    )
     msgb <- gettext(
     "operations on corresponding random variables (r.v.s); see distrARITH().\n"
                    )
     msgc <- gettext(
-    "Some functions from package 'stats' are intentionally masked\n---see distrMASK().\n"
+    "Some functions from package 'stats' are intentionally masked ---see distrMASK().\n"
                    )
     msgd <- gettext(
-    "Note that global options are controlled by distroptions()\n---c.f. ?\"distroptions\"."
+    "Note that global options are controlled by distroptions() ---c.f. ?\"distroptions\"."
                    )
 buildStartupMessage(pkg = "distr", msga, msgb, msgc, msgd, library = library, 
                     packageHelp = TRUE, 
 # MANUAL = "http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/distr.pdf",
                     VIGNETTE = gettext(
-"Package \"distrDoc\" provides a vignette to this package as well as\nto several extension packages; try vignette(\"distr\")."
+"Package \"distrDoc\" provides a vignette to this package as well as to several extension packages; try vignette(\"distr\")."
                                       )
                    )
   invisible()
 } 
 
-
 ################################
 ##
 ## Optional..-classes
